<a id="types-aiobotocore"></a>

# types-aiobotocore

[![PyPI - types-aiobotocore](https://img.shields.io/pypi/v/types-aiobotocore.svg?color=blue)](https://pypi.org/project/types-aiobotocore)
[![PyPI - Python Version](https://img.shields.io/pypi/pyversions/types-aiobotocore.svg?color=blue)](https://pypi.org/project/types-aiobotocore)
[![Docs](https://img.shields.io/readthedocs/types-aiobotocore.svg?color=blue)](https://youtype.github.io/types_aiobotocore_docs/)
[![PyPI - Downloads](https://static.pepy.tech/badge/types-aiobotocore)](https://pepy.tech/project/types-aiobotocore)

![boto3.typed](https://github.com/youtype/mypy_boto3_builder/raw/main/logo.png)

Type annotations for
[aiobotocore 2.13.1](https://github.com/aio-libs/aiobotocore) compatible with
[VSCode](https://code.visualstudio.com/),
[PyCharm](https://www.jetbrains.com/pycharm/),
[Emacs](https://www.gnu.org/software/emacs/),
[Sublime Text](https://www.sublimetext.com/),
[mypy](https://github.com/python/mypy),
[pyright](https://github.com/microsoft/pyright) and other tools.

Generated by
[mypy-boto3-builder 7.24.0](https://github.com/youtype/mypy_boto3_builder).

More information can be found in
[types-aiobotocore docs](https://youtype.github.io/types_aiobotocore_docs/).

See how it helps to find and fix potential bugs:

![boto3-stubs demo](https://github.com/youtype/mypy_boto3_builder/raw/main/demo.gif)

- [types-aiobotocore](#types-aiobotocore)
  - [How to install](#how-to-install)
    - [From PyPI with pip](#from-pypi-with-pip)
  - [How to uninstall](#how-to-uninstall)
  - [Usage](#usage)
    - [VSCode](#vscode)
    - [PyCharm](#pycharm)
    - [Emacs](#emacs)
    - [Sublime Text](#sublime-text)
    - [Other IDEs](#other-ides)
    - [mypy](#mypy)
    - [pyright](#pyright)
  - [How it works](#how-it-works)
  - [What's new](#what's-new)
    - [Implemented features](#implemented-features)
    - [Latest changes](#latest-changes)
  - [Versioning](#versioning)
  - [Thank you](#thank-you)
  - [Documentation](#documentation)
  - [Support and contributing](#support-and-contributing)
  - [Submodules](#submodules)

<a id="how-to-install"></a>

## How to install

<a id="from-pypi-with-pip"></a>

### From PyPI with pip

Install `types-aiobotocore` to add type annotations for `aiobotocore` package.

```bash
# install type annotations only for aiobotocore
python -m pip install types-aiobotocore

# install aiobotocore type annotations
# for ec2, s3, rds, lambda, sqs, dynamo and cloudformation
python -m pip install 'types-aiobotocore[essential]'

# or install annotations for services you use
python -m pip install 'types-aiobotocore[acm,apigateway]'

# or install annotations in sync with aiobotocore version
python -m pip install 'types-aiobotocore[aiobotocore]'


# Lite version does not provide session.client/resource overloads
# it is more RAM-friendly, but requires explicit type annotations
python -m pip install 'types-aiobotocore-lite[essential]'

```

<a id="how-to-uninstall"></a>

## How to uninstall

```bash
# uninstall types-aiobotocore
python -m pip uninstall -y types-aiobotocore
```

<a id="usage"></a>

## Usage

<a id="vscode"></a>

### VSCode

- Install
  [Python extension](https://marketplace.visualstudio.com/items?itemName=ms-python.python)
- Install
  [Pylance extension](https://marketplace.visualstudio.com/items?itemName=ms-python.vscode-pylance)
- Set `Pylance` as your Python Language Server
- Install `types-aiobotocore[essential]` in your environment:

```bash
python -m pip install 'types-aiobotocore[essential]'
```

Both type checking and code completion should now work. No explicit type
annotations required, write your `aiobotocore` code as usual.

<a id="pycharm"></a>

### PyCharm

Install `types-aiobotocore-lite[essential]` in your environment:

```bash
python -m pip install 'types-aiobotocore-lite[essential]'`
```

Both type checking and code completion should now work. Explicit type
annotations **are required**.

Use `types-aiobotocore` package instead for implicit type discovery.

<a id="emacs"></a>

### Emacs

- Install `types-aiobotocore` with services you use in your environment:

```bash
python -m pip install 'types-aiobotocore[essential]'
```

- Install [use-package](https://github.com/jwiegley/use-package),
  [lsp](https://github.com/emacs-lsp/lsp-mode/),
  [company](https://github.com/company-mode/company-mode) and
  [flycheck](https://github.com/flycheck/flycheck) packages
- Install [lsp-pyright](https://github.com/emacs-lsp/lsp-pyright) package

```elisp
(use-package lsp-pyright
  :ensure t
  :hook (python-mode . (lambda ()
                          (require 'lsp-pyright)
                          (lsp)))  ; or lsp-deferred
  :init (when (executable-find "python3")
          (setq lsp-pyright-python-executable-cmd "python3"))
  )
```

- Make sure emacs uses the environment where you have installed
  `types-aiobotocore`

Type checking should now work. No explicit type annotations required, write
your `aiobotocore` code as usual.

<a id="sublime-text"></a>

### Sublime Text

- Install `types-aiobotocore[essential]` with services you use in your
  environment:

```bash
python -m pip install 'types-aiobotocore[essential]'
```

- Install [LSP-pyright](https://github.com/sublimelsp/LSP-pyright) package

Type checking should now work. No explicit type annotations required, write
your `aiobotocore` code as usual.

<a id="other-ides"></a>

### Other IDEs

Not tested, but as long as your IDE supports `mypy` or `pyright`, everything
should work.

<a id="mypy"></a>

### mypy

- Install `mypy`: `python -m pip install mypy`
- Install `types-aiobotocore[essential]` in your environment:

```bash
python -m pip install 'types-aiobotocore[essential]'`
```

Type checking should now work. No explicit type annotations required, write
your `aiobotocore` code as usual.

<a id="pyright"></a>

### pyright

- Install `pyright`: `npm i -g pyright`
- Install `types-aiobotocore[essential]` in your environment:

```bash
python -m pip install 'types-aiobotocore[essential]'
```

Optionally, you can install `types-aiobotocore` to `typings` folder.

Type checking should now work. No explicit type annotations required, write
your `aiobotocore` code as usual.

<a id="how-it-works"></a>

## How it works

Fully automated
[mypy-boto3-builder](https://github.com/youtype/mypy_boto3_builder) carefully
generates type annotations for each service, patiently waiting for
`aiobotocore` updates. It delivers drop-in type annotations for you and makes
sure that:

- All available `aiobotocore` services are covered.
- Each public class and method of every `aiobotocore` service gets valid type
  annotations extracted from `botocore` schemas.
- Type annotations include up-to-date documentation.
- Link to documentation is provided for every method.
- Code is processed by [black](https://github.com/psf/black) and
  [isort](https://github.com/PyCQA/isort) for readability.

<a id="what's-new"></a>

## What's new

<a id="implemented-features"></a>

### Implemented features

- Fully type annotated `boto3`, `botocore`, `aiobotocore` and `aioboto3`
  libraries
- `mypy`, `pyright`, `VSCode`, `PyCharm`, `Sublime Text` and `Emacs`
  compatibility
- `Client`, `ServiceResource`, `Resource`, `Waiter` `Paginator` type
  annotations for each service
- Generated `TypeDefs` for each service
- Generated `Literals` for each service
- Auto discovery of types for `boto3.client` and `boto3.resource` calls
- Auto discovery of types for `session.client` and `session.resource` calls
- Auto discovery of types for `client.get_waiter` and `client.get_paginator`
  calls
- Auto discovery of types for `ServiceResource` and `Resource` collections
- Auto discovery of types for `aiobotocore.Session.create_client` calls

<a id="latest-changes"></a>

### Latest changes

Builder changelog can be found in
[Releases](https://github.com/youtype/mypy_boto3_builder/releases).

<a id="versioning"></a>

## Versioning

`types-aiobotocore` version is the same as related `aiobotocore` version and
follows [PEP 440](https://www.python.org/dev/peps/pep-0440/) format.

<a id="thank-you"></a>

## Thank you

- [Allie Fitter](https://github.com/alliefitter) for
  [boto3-type-annotations](https://pypi.org/project/boto3-type-annotations/),
  this package is based on top of his work
- [black](https://github.com/psf/black) developers for an awesome formatting
  tool
- [Timothy Edmund Crosley](https://github.com/timothycrosley) for
  [isort](https://github.com/PyCQA/isort) and how flexible it is
- [mypy](https://github.com/python/mypy) developers for doing all dirty work
  for us
- [pyright](https://github.com/microsoft/pyright) team for the new era of typed
  Python

<a id="documentation"></a>

## Documentation

All services type annotations can be found in
[aiobotocore docs](https://youtype.github.io/types_aiobotocore_docs/)

<a id="support-and-contributing"></a>

## Support and contributing

This package is auto-generated. Please reports any bugs or request new features
in [mypy-boto3-builder](https://github.com/youtype/mypy_boto3_builder/issues/)
repository.

<a id="submodules"></a>

## Submodules

- `types-aiobotocore[all]` - Type annotations for all 385 services.
- `types-aiobotocore[essential]` - Type annotations for
  [CloudFormation](https://youtype.github.io/types_aiobotocore_docs/types_aiobotocore_cloudformation/),
  [DynamoDB](https://youtype.github.io/types_aiobotocore_docs/types_aiobotocore_dynamodb/),
  [EC2](https://youtype.github.io/types_aiobotocore_docs/types_aiobotocore_ec2/),
  [Lambda](https://youtype.github.io/types_aiobotocore_docs/types_aiobotocore_lambda/),
  [RDS](https://youtype.github.io/types_aiobotocore_docs/types_aiobotocore_rds/),
  [S3](https://youtype.github.io/types_aiobotocore_docs/types_aiobotocore_s3/)
  and
  [SQS](https://youtype.github.io/types_aiobotocore_docs/types_aiobotocore_sqs/)
  services.
- `types-aiobotocore[aiobotocore]` - Install annotations in sync with
  `aiobotocore` version.
- `types-aiobotocore[accessanalyzer]` - Type annotations for
  [AccessAnalyzer](https://youtype.github.io/types_aiobotocore_docs/types_aiobotocore_accessanalyzer/)
  service.
- `types-aiobotocore[account]` - Type annotations for
  [Account](https://youtype.github.io/types_aiobotocore_docs/types_aiobotocore_account/)
  service.
- `types-aiobotocore[acm]` - Type annotations for
  [ACM](https://youtype.github.io/types_aiobotocore_docs/types_aiobotocore_acm/)
  service.
- `types-aiobotocore[acm-pca]` - Type annotations for
  [ACMPCA](https://youtype.github.io/types_aiobotocore_docs/types_aiobotocore_acm_pca/)
  service.
- `types-aiobotocore[amp]` - Type annotations for
  [PrometheusService](https://youtype.github.io/types_aiobotocore_docs/types_aiobotocore_amp/)
  service.
- `types-aiobotocore[amplify]` - Type annotations for
  [Amplify](https://youtype.github.io/types_aiobotocore_docs/types_aiobotocore_amplify/)
  service.
- `types-aiobotocore[amplifybackend]` - Type annotations for
  [AmplifyBackend](https://youtype.github.io/types_aiobotocore_docs/types_aiobotocore_amplifybackend/)
  service.
- `types-aiobotocore[amplifyuibuilder]` - Type annotations for
  [AmplifyUIBuilder](https://youtype.github.io/types_aiobotocore_docs/types_aiobotocore_amplifyuibuilder/)
  service.
- `types-aiobotocore[apigateway]` - Type annotations for
  [APIGateway](https://youtype.github.io/types_aiobotocore_docs/types_aiobotocore_apigateway/)
  service.
- `types-aiobotocore[apigatewaymanagementapi]` - Type annotations for
  [ApiGatewayManagementApi](https://youtype.github.io/types_aiobotocore_docs/types_aiobotocore_apigatewaymanagementapi/)
  service.
- `types-aiobotocore[apigatewayv2]` - Type annotations for
  [ApiGatewayV2](https://youtype.github.io/types_aiobotocore_docs/types_aiobotocore_apigatewayv2/)
  service.
- `types-aiobotocore[appconfig]` - Type annotations for
  [AppConfig](https://youtype.github.io/types_aiobotocore_docs/types_aiobotocore_appconfig/)
  service.
- `types-aiobotocore[appconfigdata]` - Type annotations for
  [AppConfigData](https://youtype.github.io/types_aiobotocore_docs/types_aiobotocore_appconfigdata/)
  service.
- `types-aiobotocore[appfabric]` - Type annotations for
  [AppFabric](https://youtype.github.io/types_aiobotocore_docs/types_aiobotocore_appfabric/)
  service.
- `types-aiobotocore[appflow]` - Type annotations for
  [Appflow](https://youtype.github.io/types_aiobotocore_docs/types_aiobotocore_appflow/)
  service.
- `types-aiobotocore[appintegrations]` - Type annotations for
  [AppIntegrationsService](https://youtype.github.io/types_aiobotocore_docs/types_aiobotocore_appintegrations/)
  service.
- `types-aiobotocore[application-autoscaling]` - Type annotations for
  [ApplicationAutoScaling](https://youtype.github.io/types_aiobotocore_docs/types_aiobotocore_application_autoscaling/)
  service.
- `types-aiobotocore[application-insights]` - Type annotations for
  [ApplicationInsights](https://youtype.github.io/types_aiobotocore_docs/types_aiobotocore_application_insights/)
  service.
- `types-aiobotocore[application-signals]` - Type annotations for
  [CloudWatchApplicationSignals](https://youtype.github.io/types_aiobotocore_docs/types_aiobotocore_application_signals/)
  service.
- `types-aiobotocore[applicationcostprofiler]` - Type annotations for
  [ApplicationCostProfiler](https://youtype.github.io/types_aiobotocore_docs/types_aiobotocore_applicationcostprofiler/)
  service.
- `types-aiobotocore[appmesh]` - Type annotations for
  [AppMesh](https://youtype.github.io/types_aiobotocore_docs/types_aiobotocore_appmesh/)
  service.
- `types-aiobotocore[apprunner]` - Type annotations for
  [AppRunner](https://youtype.github.io/types_aiobotocore_docs/types_aiobotocore_apprunner/)
  service.
- `types-aiobotocore[appstream]` - Type annotations for
  [AppStream](https://youtype.github.io/types_aiobotocore_docs/types_aiobotocore_appstream/)
  service.
- `types-aiobotocore[appsync]` - Type annotations for
  [AppSync](https://youtype.github.io/types_aiobotocore_docs/types_aiobotocore_appsync/)
  service.
- `types-aiobotocore[apptest]` - Type annotations for
  [MainframeModernizationApplicationTesting](https://youtype.github.io/types_aiobotocore_docs/types_aiobotocore_apptest/)
  service.
- `types-aiobotocore[arc-zonal-shift]` - Type annotations for
  [ARCZonalShift](https://youtype.github.io/types_aiobotocore_docs/types_aiobotocore_arc_zonal_shift/)
  service.
- `types-aiobotocore[artifact]` - Type annotations for
  [Artifact](https://youtype.github.io/types_aiobotocore_docs/types_aiobotocore_artifact/)
  service.
- `types-aiobotocore[athena]` - Type annotations for
  [Athena](https://youtype.github.io/types_aiobotocore_docs/types_aiobotocore_athena/)
  service.
- `types-aiobotocore[auditmanager]` - Type annotations for
  [AuditManager](https://youtype.github.io/types_aiobotocore_docs/types_aiobotocore_auditmanager/)
  service.
- `types-aiobotocore[autoscaling]` - Type annotations for
  [AutoScaling](https://youtype.github.io/types_aiobotocore_docs/types_aiobotocore_autoscaling/)
  service.
- `types-aiobotocore[autoscaling-plans]` - Type annotations for
  [AutoScalingPlans](https://youtype.github.io/types_aiobotocore_docs/types_aiobotocore_autoscaling_plans/)
  service.
- `types-aiobotocore[b2bi]` - Type annotations for
  [B2BI](https://youtype.github.io/types_aiobotocore_docs/types_aiobotocore_b2bi/)
  service.
- `types-aiobotocore[backup]` - Type annotations for
  [Backup](https://youtype.github.io/types_aiobotocore_docs/types_aiobotocore_backup/)
  service.
- `types-aiobotocore[backup-gateway]` - Type annotations for
  [BackupGateway](https://youtype.github.io/types_aiobotocore_docs/types_aiobotocore_backup_gateway/)
  service.
- `types-aiobotocore[batch]` - Type annotations for
  [Batch](https://youtype.github.io/types_aiobotocore_docs/types_aiobotocore_batch/)
  service.
- `types-aiobotocore[bcm-data-exports]` - Type annotations for
  [BillingandCostManagementDataExports](https://youtype.github.io/types_aiobotocore_docs/types_aiobotocore_bcm_data_exports/)
  service.
- `types-aiobotocore[bedrock]` - Type annotations for
  [Bedrock](https://youtype.github.io/types_aiobotocore_docs/types_aiobotocore_bedrock/)
  service.
- `types-aiobotocore[bedrock-agent]` - Type annotations for
  [AgentsforBedrock](https://youtype.github.io/types_aiobotocore_docs/types_aiobotocore_bedrock_agent/)
  service.
- `types-aiobotocore[bedrock-agent-runtime]` - Type annotations for
  [AgentsforBedrockRuntime](https://youtype.github.io/types_aiobotocore_docs/types_aiobotocore_bedrock_agent_runtime/)
  service.
- `types-aiobotocore[bedrock-runtime]` - Type annotations for
  [BedrockRuntime](https://youtype.github.io/types_aiobotocore_docs/types_aiobotocore_bedrock_runtime/)
  service.
- `types-aiobotocore[billingconductor]` - Type annotations for
  [BillingConductor](https://youtype.github.io/types_aiobotocore_docs/types_aiobotocore_billingconductor/)
  service.
- `types-aiobotocore[braket]` - Type annotations for
  [Braket](https://youtype.github.io/types_aiobotocore_docs/types_aiobotocore_braket/)
  service.
- `types-aiobotocore[budgets]` - Type annotations for
  [Budgets](https://youtype.github.io/types_aiobotocore_docs/types_aiobotocore_budgets/)
  service.
- `types-aiobotocore[ce]` - Type annotations for
  [CostExplorer](https://youtype.github.io/types_aiobotocore_docs/types_aiobotocore_ce/)
  service.
- `types-aiobotocore[chatbot]` - Type annotations for
  [Chatbot](https://youtype.github.io/types_aiobotocore_docs/types_aiobotocore_chatbot/)
  service.
- `types-aiobotocore[chime]` - Type annotations for
  [Chime](https://youtype.github.io/types_aiobotocore_docs/types_aiobotocore_chime/)
  service.
- `types-aiobotocore[chime-sdk-identity]` - Type annotations for
  [ChimeSDKIdentity](https://youtype.github.io/types_aiobotocore_docs/types_aiobotocore_chime_sdk_identity/)
  service.
- `types-aiobotocore[chime-sdk-media-pipelines]` - Type annotations for
  [ChimeSDKMediaPipelines](https://youtype.github.io/types_aiobotocore_docs/types_aiobotocore_chime_sdk_media_pipelines/)
  service.
- `types-aiobotocore[chime-sdk-meetings]` - Type annotations for
  [ChimeSDKMeetings](https://youtype.github.io/types_aiobotocore_docs/types_aiobotocore_chime_sdk_meetings/)
  service.
- `types-aiobotocore[chime-sdk-messaging]` - Type annotations for
  [ChimeSDKMessaging](https://youtype.github.io/types_aiobotocore_docs/types_aiobotocore_chime_sdk_messaging/)
  service.
- `types-aiobotocore[chime-sdk-voice]` - Type annotations for
  [ChimeSDKVoice](https://youtype.github.io/types_aiobotocore_docs/types_aiobotocore_chime_sdk_voice/)
  service.
- `types-aiobotocore[cleanrooms]` - Type annotations for
  [CleanRoomsService](https://youtype.github.io/types_aiobotocore_docs/types_aiobotocore_cleanrooms/)
  service.
- `types-aiobotocore[cleanroomsml]` - Type annotations for
  [CleanRoomsML](https://youtype.github.io/types_aiobotocore_docs/types_aiobotocore_cleanroomsml/)
  service.
- `types-aiobotocore[cloud9]` - Type annotations for
  [Cloud9](https://youtype.github.io/types_aiobotocore_docs/types_aiobotocore_cloud9/)
  service.
- `types-aiobotocore[cloudcontrol]` - Type annotations for
  [CloudControlApi](https://youtype.github.io/types_aiobotocore_docs/types_aiobotocore_cloudcontrol/)
  service.
- `types-aiobotocore[clouddirectory]` - Type annotations for
  [CloudDirectory](https://youtype.github.io/types_aiobotocore_docs/types_aiobotocore_clouddirectory/)
  service.
- `types-aiobotocore[cloudformation]` - Type annotations for
  [CloudFormation](https://youtype.github.io/types_aiobotocore_docs/types_aiobotocore_cloudformation/)
  service.
- `types-aiobotocore[cloudfront]` - Type annotations for
  [CloudFront](https://youtype.github.io/types_aiobotocore_docs/types_aiobotocore_cloudfront/)
  service.
- `types-aiobotocore[cloudfront-keyvaluestore]` - Type annotations for
  [CloudFrontKeyValueStore](https://youtype.github.io/types_aiobotocore_docs/types_aiobotocore_cloudfront_keyvaluestore/)
  service.
- `types-aiobotocore[cloudhsm]` - Type annotations for
  [CloudHSM](https://youtype.github.io/types_aiobotocore_docs/types_aiobotocore_cloudhsm/)
  service.
- `types-aiobotocore[cloudhsmv2]` - Type annotations for
  [CloudHSMV2](https://youtype.github.io/types_aiobotocore_docs/types_aiobotocore_cloudhsmv2/)
  service.
- `types-aiobotocore[cloudsearch]` - Type annotations for
  [CloudSearch](https://youtype.github.io/types_aiobotocore_docs/types_aiobotocore_cloudsearch/)
  service.
- `types-aiobotocore[cloudsearchdomain]` - Type annotations for
  [CloudSearchDomain](https://youtype.github.io/types_aiobotocore_docs/types_aiobotocore_cloudsearchdomain/)
  service.
- `types-aiobotocore[cloudtrail]` - Type annotations for
  [CloudTrail](https://youtype.github.io/types_aiobotocore_docs/types_aiobotocore_cloudtrail/)
  service.
- `types-aiobotocore[cloudtrail-data]` - Type annotations for
  [CloudTrailDataService](https://youtype.github.io/types_aiobotocore_docs/types_aiobotocore_cloudtrail_data/)
  service.
- `types-aiobotocore[cloudwatch]` - Type annotations for
  [CloudWatch](https://youtype.github.io/types_aiobotocore_docs/types_aiobotocore_cloudwatch/)
  service.
- `types-aiobotocore[codeartifact]` - Type annotations for
  [CodeArtifact](https://youtype.github.io/types_aiobotocore_docs/types_aiobotocore_codeartifact/)
  service.
- `types-aiobotocore[codebuild]` - Type annotations for
  [CodeBuild](https://youtype.github.io/types_aiobotocore_docs/types_aiobotocore_codebuild/)
  service.
- `types-aiobotocore[codecatalyst]` - Type annotations for
  [CodeCatalyst](https://youtype.github.io/types_aiobotocore_docs/types_aiobotocore_codecatalyst/)
  service.
- `types-aiobotocore[codecommit]` - Type annotations for
  [CodeCommit](https://youtype.github.io/types_aiobotocore_docs/types_aiobotocore_codecommit/)
  service.
- `types-aiobotocore[codeconnections]` - Type annotations for
  [CodeConnections](https://youtype.github.io/types_aiobotocore_docs/types_aiobotocore_codeconnections/)
  service.
- `types-aiobotocore[codedeploy]` - Type annotations for
  [CodeDeploy](https://youtype.github.io/types_aiobotocore_docs/types_aiobotocore_codedeploy/)
  service.
- `types-aiobotocore[codeguru-reviewer]` - Type annotations for
  [CodeGuruReviewer](https://youtype.github.io/types_aiobotocore_docs/types_aiobotocore_codeguru_reviewer/)
  service.
- `types-aiobotocore[codeguru-security]` - Type annotations for
  [CodeGuruSecurity](https://youtype.github.io/types_aiobotocore_docs/types_aiobotocore_codeguru_security/)
  service.
- `types-aiobotocore[codeguruprofiler]` - Type annotations for
  [CodeGuruProfiler](https://youtype.github.io/types_aiobotocore_docs/types_aiobotocore_codeguruprofiler/)
  service.
- `types-aiobotocore[codepipeline]` - Type annotations for
  [CodePipeline](https://youtype.github.io/types_aiobotocore_docs/types_aiobotocore_codepipeline/)
  service.
- `types-aiobotocore[codestar]` - Type annotations for
  [CodeStar](https://youtype.github.io/types_aiobotocore_docs/types_aiobotocore_codestar/)
  service.
- `types-aiobotocore[codestar-connections]` - Type annotations for
  [CodeStarconnections](https://youtype.github.io/types_aiobotocore_docs/types_aiobotocore_codestar_connections/)
  service.
- `types-aiobotocore[codestar-notifications]` - Type annotations for
  [CodeStarNotifications](https://youtype.github.io/types_aiobotocore_docs/types_aiobotocore_codestar_notifications/)
  service.
- `types-aiobotocore[cognito-identity]` - Type annotations for
  [CognitoIdentity](https://youtype.github.io/types_aiobotocore_docs/types_aiobotocore_cognito_identity/)
  service.
- `types-aiobotocore[cognito-idp]` - Type annotations for
  [CognitoIdentityProvider](https://youtype.github.io/types_aiobotocore_docs/types_aiobotocore_cognito_idp/)
  service.
- `types-aiobotocore[cognito-sync]` - Type annotations for
  [CognitoSync](https://youtype.github.io/types_aiobotocore_docs/types_aiobotocore_cognito_sync/)
  service.
- `types-aiobotocore[comprehend]` - Type annotations for
  [Comprehend](https://youtype.github.io/types_aiobotocore_docs/types_aiobotocore_comprehend/)
  service.
- `types-aiobotocore[comprehendmedical]` - Type annotations for
  [ComprehendMedical](https://youtype.github.io/types_aiobotocore_docs/types_aiobotocore_comprehendmedical/)
  service.
- `types-aiobotocore[compute-optimizer]` - Type annotations for
  [ComputeOptimizer](https://youtype.github.io/types_aiobotocore_docs/types_aiobotocore_compute_optimizer/)
  service.
- `types-aiobotocore[config]` - Type annotations for
  [ConfigService](https://youtype.github.io/types_aiobotocore_docs/types_aiobotocore_config/)
  service.
- `types-aiobotocore[connect]` - Type annotations for
  [Connect](https://youtype.github.io/types_aiobotocore_docs/types_aiobotocore_connect/)
  service.
- `types-aiobotocore[connect-contact-lens]` - Type annotations for
  [ConnectContactLens](https://youtype.github.io/types_aiobotocore_docs/types_aiobotocore_connect_contact_lens/)
  service.
- `types-aiobotocore[connectcampaigns]` - Type annotations for
  [ConnectCampaignService](https://youtype.github.io/types_aiobotocore_docs/types_aiobotocore_connectcampaigns/)
  service.
- `types-aiobotocore[connectcases]` - Type annotations for
  [ConnectCases](https://youtype.github.io/types_aiobotocore_docs/types_aiobotocore_connectcases/)
  service.
- `types-aiobotocore[connectparticipant]` - Type annotations for
  [ConnectParticipant](https://youtype.github.io/types_aiobotocore_docs/types_aiobotocore_connectparticipant/)
  service.
- `types-aiobotocore[controlcatalog]` - Type annotations for
  [ControlCatalog](https://youtype.github.io/types_aiobotocore_docs/types_aiobotocore_controlcatalog/)
  service.
- `types-aiobotocore[controltower]` - Type annotations for
  [ControlTower](https://youtype.github.io/types_aiobotocore_docs/types_aiobotocore_controltower/)
  service.
- `types-aiobotocore[cost-optimization-hub]` - Type annotations for
  [CostOptimizationHub](https://youtype.github.io/types_aiobotocore_docs/types_aiobotocore_cost_optimization_hub/)
  service.
- `types-aiobotocore[cur]` - Type annotations for
  [CostandUsageReportService](https://youtype.github.io/types_aiobotocore_docs/types_aiobotocore_cur/)
  service.
- `types-aiobotocore[customer-profiles]` - Type annotations for
  [CustomerProfiles](https://youtype.github.io/types_aiobotocore_docs/types_aiobotocore_customer_profiles/)
  service.
- `types-aiobotocore[databrew]` - Type annotations for
  [GlueDataBrew](https://youtype.github.io/types_aiobotocore_docs/types_aiobotocore_databrew/)
  service.
- `types-aiobotocore[dataexchange]` - Type annotations for
  [DataExchange](https://youtype.github.io/types_aiobotocore_docs/types_aiobotocore_dataexchange/)
  service.
- `types-aiobotocore[datapipeline]` - Type annotations for
  [DataPipeline](https://youtype.github.io/types_aiobotocore_docs/types_aiobotocore_datapipeline/)
  service.
- `types-aiobotocore[datasync]` - Type annotations for
  [DataSync](https://youtype.github.io/types_aiobotocore_docs/types_aiobotocore_datasync/)
  service.
- `types-aiobotocore[datazone]` - Type annotations for
  [DataZone](https://youtype.github.io/types_aiobotocore_docs/types_aiobotocore_datazone/)
  service.
- `types-aiobotocore[dax]` - Type annotations for
  [DAX](https://youtype.github.io/types_aiobotocore_docs/types_aiobotocore_dax/)
  service.
- `types-aiobotocore[deadline]` - Type annotations for
  [DeadlineCloud](https://youtype.github.io/types_aiobotocore_docs/types_aiobotocore_deadline/)
  service.
- `types-aiobotocore[detective]` - Type annotations for
  [Detective](https://youtype.github.io/types_aiobotocore_docs/types_aiobotocore_detective/)
  service.
- `types-aiobotocore[devicefarm]` - Type annotations for
  [DeviceFarm](https://youtype.github.io/types_aiobotocore_docs/types_aiobotocore_devicefarm/)
  service.
- `types-aiobotocore[devops-guru]` - Type annotations for
  [DevOpsGuru](https://youtype.github.io/types_aiobotocore_docs/types_aiobotocore_devops_guru/)
  service.
- `types-aiobotocore[directconnect]` - Type annotations for
  [DirectConnect](https://youtype.github.io/types_aiobotocore_docs/types_aiobotocore_directconnect/)
  service.
- `types-aiobotocore[discovery]` - Type annotations for
  [ApplicationDiscoveryService](https://youtype.github.io/types_aiobotocore_docs/types_aiobotocore_discovery/)
  service.
- `types-aiobotocore[dlm]` - Type annotations for
  [DLM](https://youtype.github.io/types_aiobotocore_docs/types_aiobotocore_dlm/)
  service.
- `types-aiobotocore[dms]` - Type annotations for
  [DatabaseMigrationService](https://youtype.github.io/types_aiobotocore_docs/types_aiobotocore_dms/)
  service.
- `types-aiobotocore[docdb]` - Type annotations for
  [DocDB](https://youtype.github.io/types_aiobotocore_docs/types_aiobotocore_docdb/)
  service.
- `types-aiobotocore[docdb-elastic]` - Type annotations for
  [DocDBElastic](https://youtype.github.io/types_aiobotocore_docs/types_aiobotocore_docdb_elastic/)
  service.
- `types-aiobotocore[drs]` - Type annotations for
  [Drs](https://youtype.github.io/types_aiobotocore_docs/types_aiobotocore_drs/)
  service.
- `types-aiobotocore[ds]` - Type annotations for
  [DirectoryService](https://youtype.github.io/types_aiobotocore_docs/types_aiobotocore_ds/)
  service.
- `types-aiobotocore[dynamodb]` - Type annotations for
  [DynamoDB](https://youtype.github.io/types_aiobotocore_docs/types_aiobotocore_dynamodb/)
  service.
- `types-aiobotocore[dynamodbstreams]` - Type annotations for
  [DynamoDBStreams](https://youtype.github.io/types_aiobotocore_docs/types_aiobotocore_dynamodbstreams/)
  service.
- `types-aiobotocore[ebs]` - Type annotations for
  [EBS](https://youtype.github.io/types_aiobotocore_docs/types_aiobotocore_ebs/)
  service.
- `types-aiobotocore[ec2]` - Type annotations for
  [EC2](https://youtype.github.io/types_aiobotocore_docs/types_aiobotocore_ec2/)
  service.
- `types-aiobotocore[ec2-instance-connect]` - Type annotations for
  [EC2InstanceConnect](https://youtype.github.io/types_aiobotocore_docs/types_aiobotocore_ec2_instance_connect/)
  service.
- `types-aiobotocore[ecr]` - Type annotations for
  [ECR](https://youtype.github.io/types_aiobotocore_docs/types_aiobotocore_ecr/)
  service.
- `types-aiobotocore[ecr-public]` - Type annotations for
  [ECRPublic](https://youtype.github.io/types_aiobotocore_docs/types_aiobotocore_ecr_public/)
  service.
- `types-aiobotocore[ecs]` - Type annotations for
  [ECS](https://youtype.github.io/types_aiobotocore_docs/types_aiobotocore_ecs/)
  service.
- `types-aiobotocore[efs]` - Type annotations for
  [EFS](https://youtype.github.io/types_aiobotocore_docs/types_aiobotocore_efs/)
  service.
- `types-aiobotocore[eks]` - Type annotations for
  [EKS](https://youtype.github.io/types_aiobotocore_docs/types_aiobotocore_eks/)
  service.
- `types-aiobotocore[eks-auth]` - Type annotations for
  [EKSAuth](https://youtype.github.io/types_aiobotocore_docs/types_aiobotocore_eks_auth/)
  service.
- `types-aiobotocore[elastic-inference]` - Type annotations for
  [ElasticInference](https://youtype.github.io/types_aiobotocore_docs/types_aiobotocore_elastic_inference/)
  service.
- `types-aiobotocore[elasticache]` - Type annotations for
  [ElastiCache](https://youtype.github.io/types_aiobotocore_docs/types_aiobotocore_elasticache/)
  service.
- `types-aiobotocore[elasticbeanstalk]` - Type annotations for
  [ElasticBeanstalk](https://youtype.github.io/types_aiobotocore_docs/types_aiobotocore_elasticbeanstalk/)
  service.
- `types-aiobotocore[elastictranscoder]` - Type annotations for
  [ElasticTranscoder](https://youtype.github.io/types_aiobotocore_docs/types_aiobotocore_elastictranscoder/)
  service.
- `types-aiobotocore[elb]` - Type annotations for
  [ElasticLoadBalancing](https://youtype.github.io/types_aiobotocore_docs/types_aiobotocore_elb/)
  service.
- `types-aiobotocore[elbv2]` - Type annotations for
  [ElasticLoadBalancingv2](https://youtype.github.io/types_aiobotocore_docs/types_aiobotocore_elbv2/)
  service.
- `types-aiobotocore[emr]` - Type annotations for
  [EMR](https://youtype.github.io/types_aiobotocore_docs/types_aiobotocore_emr/)
  service.
- `types-aiobotocore[emr-containers]` - Type annotations for
  [EMRContainers](https://youtype.github.io/types_aiobotocore_docs/types_aiobotocore_emr_containers/)
  service.
- `types-aiobotocore[emr-serverless]` - Type annotations for
  [EMRServerless](https://youtype.github.io/types_aiobotocore_docs/types_aiobotocore_emr_serverless/)
  service.
- `types-aiobotocore[entityresolution]` - Type annotations for
  [EntityResolution](https://youtype.github.io/types_aiobotocore_docs/types_aiobotocore_entityresolution/)
  service.
- `types-aiobotocore[es]` - Type annotations for
  [ElasticsearchService](https://youtype.github.io/types_aiobotocore_docs/types_aiobotocore_es/)
  service.
- `types-aiobotocore[events]` - Type annotations for
  [EventBridge](https://youtype.github.io/types_aiobotocore_docs/types_aiobotocore_events/)
  service.
- `types-aiobotocore[evidently]` - Type annotations for
  [CloudWatchEvidently](https://youtype.github.io/types_aiobotocore_docs/types_aiobotocore_evidently/)
  service.
- `types-aiobotocore[finspace]` - Type annotations for
  [Finspace](https://youtype.github.io/types_aiobotocore_docs/types_aiobotocore_finspace/)
  service.
- `types-aiobotocore[finspace-data]` - Type annotations for
  [FinSpaceData](https://youtype.github.io/types_aiobotocore_docs/types_aiobotocore_finspace_data/)
  service.
- `types-aiobotocore[firehose]` - Type annotations for
  [Firehose](https://youtype.github.io/types_aiobotocore_docs/types_aiobotocore_firehose/)
  service.
- `types-aiobotocore[fis]` - Type annotations for
  [FIS](https://youtype.github.io/types_aiobotocore_docs/types_aiobotocore_fis/)
  service.
- `types-aiobotocore[fms]` - Type annotations for
  [FMS](https://youtype.github.io/types_aiobotocore_docs/types_aiobotocore_fms/)
  service.
- `types-aiobotocore[forecast]` - Type annotations for
  [ForecastService](https://youtype.github.io/types_aiobotocore_docs/types_aiobotocore_forecast/)
  service.
- `types-aiobotocore[forecastquery]` - Type annotations for
  [ForecastQueryService](https://youtype.github.io/types_aiobotocore_docs/types_aiobotocore_forecastquery/)
  service.
- `types-aiobotocore[frauddetector]` - Type annotations for
  [FraudDetector](https://youtype.github.io/types_aiobotocore_docs/types_aiobotocore_frauddetector/)
  service.
- `types-aiobotocore[freetier]` - Type annotations for
  [FreeTier](https://youtype.github.io/types_aiobotocore_docs/types_aiobotocore_freetier/)
  service.
- `types-aiobotocore[fsx]` - Type annotations for
  [FSx](https://youtype.github.io/types_aiobotocore_docs/types_aiobotocore_fsx/)
  service.
- `types-aiobotocore[gamelift]` - Type annotations for
  [GameLift](https://youtype.github.io/types_aiobotocore_docs/types_aiobotocore_gamelift/)
  service.
- `types-aiobotocore[glacier]` - Type annotations for
  [Glacier](https://youtype.github.io/types_aiobotocore_docs/types_aiobotocore_glacier/)
  service.
- `types-aiobotocore[globalaccelerator]` - Type annotations for
  [GlobalAccelerator](https://youtype.github.io/types_aiobotocore_docs/types_aiobotocore_globalaccelerator/)
  service.
- `types-aiobotocore[glue]` - Type annotations for
  [Glue](https://youtype.github.io/types_aiobotocore_docs/types_aiobotocore_glue/)
  service.
- `types-aiobotocore[grafana]` - Type annotations for
  [ManagedGrafana](https://youtype.github.io/types_aiobotocore_docs/types_aiobotocore_grafana/)
  service.
- `types-aiobotocore[greengrass]` - Type annotations for
  [Greengrass](https://youtype.github.io/types_aiobotocore_docs/types_aiobotocore_greengrass/)
  service.
- `types-aiobotocore[greengrassv2]` - Type annotations for
  [GreengrassV2](https://youtype.github.io/types_aiobotocore_docs/types_aiobotocore_greengrassv2/)
  service.
- `types-aiobotocore[groundstation]` - Type annotations for
  [GroundStation](https://youtype.github.io/types_aiobotocore_docs/types_aiobotocore_groundstation/)
  service.
- `types-aiobotocore[guardduty]` - Type annotations for
  [GuardDuty](https://youtype.github.io/types_aiobotocore_docs/types_aiobotocore_guardduty/)
  service.
- `types-aiobotocore[health]` - Type annotations for
  [Health](https://youtype.github.io/types_aiobotocore_docs/types_aiobotocore_health/)
  service.
- `types-aiobotocore[healthlake]` - Type annotations for
  [HealthLake](https://youtype.github.io/types_aiobotocore_docs/types_aiobotocore_healthlake/)
  service.
- `types-aiobotocore[iam]` - Type annotations for
  [IAM](https://youtype.github.io/types_aiobotocore_docs/types_aiobotocore_iam/)
  service.
- `types-aiobotocore[identitystore]` - Type annotations for
  [IdentityStore](https://youtype.github.io/types_aiobotocore_docs/types_aiobotocore_identitystore/)
  service.
- `types-aiobotocore[imagebuilder]` - Type annotations for
  [Imagebuilder](https://youtype.github.io/types_aiobotocore_docs/types_aiobotocore_imagebuilder/)
  service.
- `types-aiobotocore[importexport]` - Type annotations for
  [ImportExport](https://youtype.github.io/types_aiobotocore_docs/types_aiobotocore_importexport/)
  service.
- `types-aiobotocore[inspector]` - Type annotations for
  [Inspector](https://youtype.github.io/types_aiobotocore_docs/types_aiobotocore_inspector/)
  service.
- `types-aiobotocore[inspector-scan]` - Type annotations for
  [Inspectorscan](https://youtype.github.io/types_aiobotocore_docs/types_aiobotocore_inspector_scan/)
  service.
- `types-aiobotocore[inspector2]` - Type annotations for
  [Inspector2](https://youtype.github.io/types_aiobotocore_docs/types_aiobotocore_inspector2/)
  service.
- `types-aiobotocore[internetmonitor]` - Type annotations for
  [CloudWatchInternetMonitor](https://youtype.github.io/types_aiobotocore_docs/types_aiobotocore_internetmonitor/)
  service.
- `types-aiobotocore[iot]` - Type annotations for
  [IoT](https://youtype.github.io/types_aiobotocore_docs/types_aiobotocore_iot/)
  service.
- `types-aiobotocore[iot-data]` - Type annotations for
  [IoTDataPlane](https://youtype.github.io/types_aiobotocore_docs/types_aiobotocore_iot_data/)
  service.
- `types-aiobotocore[iot-jobs-data]` - Type annotations for
  [IoTJobsDataPlane](https://youtype.github.io/types_aiobotocore_docs/types_aiobotocore_iot_jobs_data/)
  service.
- `types-aiobotocore[iot1click-devices]` - Type annotations for
  [IoT1ClickDevicesService](https://youtype.github.io/types_aiobotocore_docs/types_aiobotocore_iot1click_devices/)
  service.
- `types-aiobotocore[iot1click-projects]` - Type annotations for
  [IoT1ClickProjects](https://youtype.github.io/types_aiobotocore_docs/types_aiobotocore_iot1click_projects/)
  service.
- `types-aiobotocore[iotanalytics]` - Type annotations for
  [IoTAnalytics](https://youtype.github.io/types_aiobotocore_docs/types_aiobotocore_iotanalytics/)
  service.
- `types-aiobotocore[iotdeviceadvisor]` - Type annotations for
  [IoTDeviceAdvisor](https://youtype.github.io/types_aiobotocore_docs/types_aiobotocore_iotdeviceadvisor/)
  service.
- `types-aiobotocore[iotevents]` - Type annotations for
  [IoTEvents](https://youtype.github.io/types_aiobotocore_docs/types_aiobotocore_iotevents/)
  service.
- `types-aiobotocore[iotevents-data]` - Type annotations for
  [IoTEventsData](https://youtype.github.io/types_aiobotocore_docs/types_aiobotocore_iotevents_data/)
  service.
- `types-aiobotocore[iotfleethub]` - Type annotations for
  [IoTFleetHub](https://youtype.github.io/types_aiobotocore_docs/types_aiobotocore_iotfleethub/)
  service.
- `types-aiobotocore[iotfleetwise]` - Type annotations for
  [IoTFleetWise](https://youtype.github.io/types_aiobotocore_docs/types_aiobotocore_iotfleetwise/)
  service.
- `types-aiobotocore[iotsecuretunneling]` - Type annotations for
  [IoTSecureTunneling](https://youtype.github.io/types_aiobotocore_docs/types_aiobotocore_iotsecuretunneling/)
  service.
- `types-aiobotocore[iotsitewise]` - Type annotations for
  [IoTSiteWise](https://youtype.github.io/types_aiobotocore_docs/types_aiobotocore_iotsitewise/)
  service.
- `types-aiobotocore[iotthingsgraph]` - Type annotations for
  [IoTThingsGraph](https://youtype.github.io/types_aiobotocore_docs/types_aiobotocore_iotthingsgraph/)
  service.
- `types-aiobotocore[iottwinmaker]` - Type annotations for
  [IoTTwinMaker](https://youtype.github.io/types_aiobotocore_docs/types_aiobotocore_iottwinmaker/)
  service.
- `types-aiobotocore[iotwireless]` - Type annotations for
  [IoTWireless](https://youtype.github.io/types_aiobotocore_docs/types_aiobotocore_iotwireless/)
  service.
- `types-aiobotocore[ivs]` - Type annotations for
  [IVS](https://youtype.github.io/types_aiobotocore_docs/types_aiobotocore_ivs/)
  service.
- `types-aiobotocore[ivs-realtime]` - Type annotations for
  [Ivsrealtime](https://youtype.github.io/types_aiobotocore_docs/types_aiobotocore_ivs_realtime/)
  service.
- `types-aiobotocore[ivschat]` - Type annotations for
  [Ivschat](https://youtype.github.io/types_aiobotocore_docs/types_aiobotocore_ivschat/)
  service.
- `types-aiobotocore[kafka]` - Type annotations for
  [Kafka](https://youtype.github.io/types_aiobotocore_docs/types_aiobotocore_kafka/)
  service.
- `types-aiobotocore[kafkaconnect]` - Type annotations for
  [KafkaConnect](https://youtype.github.io/types_aiobotocore_docs/types_aiobotocore_kafkaconnect/)
  service.
- `types-aiobotocore[kendra]` - Type annotations for
  [Kendra](https://youtype.github.io/types_aiobotocore_docs/types_aiobotocore_kendra/)
  service.
- `types-aiobotocore[kendra-ranking]` - Type annotations for
  [KendraRanking](https://youtype.github.io/types_aiobotocore_docs/types_aiobotocore_kendra_ranking/)
  service.
- `types-aiobotocore[keyspaces]` - Type annotations for
  [Keyspaces](https://youtype.github.io/types_aiobotocore_docs/types_aiobotocore_keyspaces/)
  service.
- `types-aiobotocore[kinesis]` - Type annotations for
  [Kinesis](https://youtype.github.io/types_aiobotocore_docs/types_aiobotocore_kinesis/)
  service.
- `types-aiobotocore[kinesis-video-archived-media]` - Type annotations for
  [KinesisVideoArchivedMedia](https://youtype.github.io/types_aiobotocore_docs/types_aiobotocore_kinesis_video_archived_media/)
  service.
- `types-aiobotocore[kinesis-video-media]` - Type annotations for
  [KinesisVideoMedia](https://youtype.github.io/types_aiobotocore_docs/types_aiobotocore_kinesis_video_media/)
  service.
- `types-aiobotocore[kinesis-video-signaling]` - Type annotations for
  [KinesisVideoSignalingChannels](https://youtype.github.io/types_aiobotocore_docs/types_aiobotocore_kinesis_video_signaling/)
  service.
- `types-aiobotocore[kinesis-video-webrtc-storage]` - Type annotations for
  [KinesisVideoWebRTCStorage](https://youtype.github.io/types_aiobotocore_docs/types_aiobotocore_kinesis_video_webrtc_storage/)
  service.
- `types-aiobotocore[kinesisanalytics]` - Type annotations for
  [KinesisAnalytics](https://youtype.github.io/types_aiobotocore_docs/types_aiobotocore_kinesisanalytics/)
  service.
- `types-aiobotocore[kinesisanalyticsv2]` - Type annotations for
  [KinesisAnalyticsV2](https://youtype.github.io/types_aiobotocore_docs/types_aiobotocore_kinesisanalyticsv2/)
  service.
- `types-aiobotocore[kinesisvideo]` - Type annotations for
  [KinesisVideo](https://youtype.github.io/types_aiobotocore_docs/types_aiobotocore_kinesisvideo/)
  service.
- `types-aiobotocore[kms]` - Type annotations for
  [KMS](https://youtype.github.io/types_aiobotocore_docs/types_aiobotocore_kms/)
  service.
- `types-aiobotocore[lakeformation]` - Type annotations for
  [LakeFormation](https://youtype.github.io/types_aiobotocore_docs/types_aiobotocore_lakeformation/)
  service.
- `types-aiobotocore[lambda]` - Type annotations for
  [Lambda](https://youtype.github.io/types_aiobotocore_docs/types_aiobotocore_lambda/)
  service.
- `types-aiobotocore[launch-wizard]` - Type annotations for
  [LaunchWizard](https://youtype.github.io/types_aiobotocore_docs/types_aiobotocore_launch_wizard/)
  service.
- `types-aiobotocore[lex-models]` - Type annotations for
  [LexModelBuildingService](https://youtype.github.io/types_aiobotocore_docs/types_aiobotocore_lex_models/)
  service.
- `types-aiobotocore[lex-runtime]` - Type annotations for
  [LexRuntimeService](https://youtype.github.io/types_aiobotocore_docs/types_aiobotocore_lex_runtime/)
  service.
- `types-aiobotocore[lexv2-models]` - Type annotations for
  [LexModelsV2](https://youtype.github.io/types_aiobotocore_docs/types_aiobotocore_lexv2_models/)
  service.
- `types-aiobotocore[lexv2-runtime]` - Type annotations for
  [LexRuntimeV2](https://youtype.github.io/types_aiobotocore_docs/types_aiobotocore_lexv2_runtime/)
  service.
- `types-aiobotocore[license-manager]` - Type annotations for
  [LicenseManager](https://youtype.github.io/types_aiobotocore_docs/types_aiobotocore_license_manager/)
  service.
- `types-aiobotocore[license-manager-linux-subscriptions]` - Type annotations
  for
  [LicenseManagerLinuxSubscriptions](https://youtype.github.io/types_aiobotocore_docs/types_aiobotocore_license_manager_linux_subscriptions/)
  service.
- `types-aiobotocore[license-manager-user-subscriptions]` - Type annotations
  for
  [LicenseManagerUserSubscriptions](https://youtype.github.io/types_aiobotocore_docs/types_aiobotocore_license_manager_user_subscriptions/)
  service.
- `types-aiobotocore[lightsail]` - Type annotations for
  [Lightsail](https://youtype.github.io/types_aiobotocore_docs/types_aiobotocore_lightsail/)
  service.
- `types-aiobotocore[location]` - Type annotations for
  [LocationService](https://youtype.github.io/types_aiobotocore_docs/types_aiobotocore_location/)
  service.
- `types-aiobotocore[logs]` - Type annotations for
  [CloudWatchLogs](https://youtype.github.io/types_aiobotocore_docs/types_aiobotocore_logs/)
  service.
- `types-aiobotocore[lookoutequipment]` - Type annotations for
  [LookoutEquipment](https://youtype.github.io/types_aiobotocore_docs/types_aiobotocore_lookoutequipment/)
  service.
- `types-aiobotocore[lookoutmetrics]` - Type annotations for
  [LookoutMetrics](https://youtype.github.io/types_aiobotocore_docs/types_aiobotocore_lookoutmetrics/)
  service.
- `types-aiobotocore[lookoutvision]` - Type annotations for
  [LookoutforVision](https://youtype.github.io/types_aiobotocore_docs/types_aiobotocore_lookoutvision/)
  service.
- `types-aiobotocore[m2]` - Type annotations for
  [MainframeModernization](https://youtype.github.io/types_aiobotocore_docs/types_aiobotocore_m2/)
  service.
- `types-aiobotocore[machinelearning]` - Type annotations for
  [MachineLearning](https://youtype.github.io/types_aiobotocore_docs/types_aiobotocore_machinelearning/)
  service.
- `types-aiobotocore[macie2]` - Type annotations for
  [Macie2](https://youtype.github.io/types_aiobotocore_docs/types_aiobotocore_macie2/)
  service.
- `types-aiobotocore[mailmanager]` - Type annotations for
  [MailManager](https://youtype.github.io/types_aiobotocore_docs/types_aiobotocore_mailmanager/)
  service.
- `types-aiobotocore[managedblockchain]` - Type annotations for
  [ManagedBlockchain](https://youtype.github.io/types_aiobotocore_docs/types_aiobotocore_managedblockchain/)
  service.
- `types-aiobotocore[managedblockchain-query]` - Type annotations for
  [ManagedBlockchainQuery](https://youtype.github.io/types_aiobotocore_docs/types_aiobotocore_managedblockchain_query/)
  service.
- `types-aiobotocore[marketplace-agreement]` - Type annotations for
  [AgreementService](https://youtype.github.io/types_aiobotocore_docs/types_aiobotocore_marketplace_agreement/)
  service.
- `types-aiobotocore[marketplace-catalog]` - Type annotations for
  [MarketplaceCatalog](https://youtype.github.io/types_aiobotocore_docs/types_aiobotocore_marketplace_catalog/)
  service.
- `types-aiobotocore[marketplace-deployment]` - Type annotations for
  [MarketplaceDeploymentService](https://youtype.github.io/types_aiobotocore_docs/types_aiobotocore_marketplace_deployment/)
  service.
- `types-aiobotocore[marketplace-entitlement]` - Type annotations for
  [MarketplaceEntitlementService](https://youtype.github.io/types_aiobotocore_docs/types_aiobotocore_marketplace_entitlement/)
  service.
- `types-aiobotocore[marketplacecommerceanalytics]` - Type annotations for
  [MarketplaceCommerceAnalytics](https://youtype.github.io/types_aiobotocore_docs/types_aiobotocore_marketplacecommerceanalytics/)
  service.
- `types-aiobotocore[mediaconnect]` - Type annotations for
  [MediaConnect](https://youtype.github.io/types_aiobotocore_docs/types_aiobotocore_mediaconnect/)
  service.
- `types-aiobotocore[mediaconvert]` - Type annotations for
  [MediaConvert](https://youtype.github.io/types_aiobotocore_docs/types_aiobotocore_mediaconvert/)
  service.
- `types-aiobotocore[medialive]` - Type annotations for
  [MediaLive](https://youtype.github.io/types_aiobotocore_docs/types_aiobotocore_medialive/)
  service.
- `types-aiobotocore[mediapackage]` - Type annotations for
  [MediaPackage](https://youtype.github.io/types_aiobotocore_docs/types_aiobotocore_mediapackage/)
  service.
- `types-aiobotocore[mediapackage-vod]` - Type annotations for
  [MediaPackageVod](https://youtype.github.io/types_aiobotocore_docs/types_aiobotocore_mediapackage_vod/)
  service.
- `types-aiobotocore[mediapackagev2]` - Type annotations for
  [Mediapackagev2](https://youtype.github.io/types_aiobotocore_docs/types_aiobotocore_mediapackagev2/)
  service.
- `types-aiobotocore[mediastore]` - Type annotations for
  [MediaStore](https://youtype.github.io/types_aiobotocore_docs/types_aiobotocore_mediastore/)
  service.
- `types-aiobotocore[mediastore-data]` - Type annotations for
  [MediaStoreData](https://youtype.github.io/types_aiobotocore_docs/types_aiobotocore_mediastore_data/)
  service.
- `types-aiobotocore[mediatailor]` - Type annotations for
  [MediaTailor](https://youtype.github.io/types_aiobotocore_docs/types_aiobotocore_mediatailor/)
  service.
- `types-aiobotocore[medical-imaging]` - Type annotations for
  [HealthImaging](https://youtype.github.io/types_aiobotocore_docs/types_aiobotocore_medical_imaging/)
  service.
- `types-aiobotocore[memorydb]` - Type annotations for
  [MemoryDB](https://youtype.github.io/types_aiobotocore_docs/types_aiobotocore_memorydb/)
  service.
- `types-aiobotocore[meteringmarketplace]` - Type annotations for
  [MarketplaceMetering](https://youtype.github.io/types_aiobotocore_docs/types_aiobotocore_meteringmarketplace/)
  service.
- `types-aiobotocore[mgh]` - Type annotations for
  [MigrationHub](https://youtype.github.io/types_aiobotocore_docs/types_aiobotocore_mgh/)
  service.
- `types-aiobotocore[mgn]` - Type annotations for
  [Mgn](https://youtype.github.io/types_aiobotocore_docs/types_aiobotocore_mgn/)
  service.
- `types-aiobotocore[migration-hub-refactor-spaces]` - Type annotations for
  [MigrationHubRefactorSpaces](https://youtype.github.io/types_aiobotocore_docs/types_aiobotocore_migration_hub_refactor_spaces/)
  service.
- `types-aiobotocore[migrationhub-config]` - Type annotations for
  [MigrationHubConfig](https://youtype.github.io/types_aiobotocore_docs/types_aiobotocore_migrationhub_config/)
  service.
- `types-aiobotocore[migrationhuborchestrator]` - Type annotations for
  [MigrationHubOrchestrator](https://youtype.github.io/types_aiobotocore_docs/types_aiobotocore_migrationhuborchestrator/)
  service.
- `types-aiobotocore[migrationhubstrategy]` - Type annotations for
  [MigrationHubStrategyRecommendations](https://youtype.github.io/types_aiobotocore_docs/types_aiobotocore_migrationhubstrategy/)
  service.
- `types-aiobotocore[mobile]` - Type annotations for
  [Mobile](https://youtype.github.io/types_aiobotocore_docs/types_aiobotocore_mobile/)
  service.
- `types-aiobotocore[mq]` - Type annotations for
  [MQ](https://youtype.github.io/types_aiobotocore_docs/types_aiobotocore_mq/)
  service.
- `types-aiobotocore[mturk]` - Type annotations for
  [MTurk](https://youtype.github.io/types_aiobotocore_docs/types_aiobotocore_mturk/)
  service.
- `types-aiobotocore[mwaa]` - Type annotations for
  [MWAA](https://youtype.github.io/types_aiobotocore_docs/types_aiobotocore_mwaa/)
  service.
- `types-aiobotocore[neptune]` - Type annotations for
  [Neptune](https://youtype.github.io/types_aiobotocore_docs/types_aiobotocore_neptune/)
  service.
- `types-aiobotocore[neptune-graph]` - Type annotations for
  [NeptuneGraph](https://youtype.github.io/types_aiobotocore_docs/types_aiobotocore_neptune_graph/)
  service.
- `types-aiobotocore[neptunedata]` - Type annotations for
  [NeptuneData](https://youtype.github.io/types_aiobotocore_docs/types_aiobotocore_neptunedata/)
  service.
- `types-aiobotocore[network-firewall]` - Type annotations for
  [NetworkFirewall](https://youtype.github.io/types_aiobotocore_docs/types_aiobotocore_network_firewall/)
  service.
- `types-aiobotocore[networkmanager]` - Type annotations for
  [NetworkManager](https://youtype.github.io/types_aiobotocore_docs/types_aiobotocore_networkmanager/)
  service.
- `types-aiobotocore[networkmonitor]` - Type annotations for
  [CloudWatchNetworkMonitor](https://youtype.github.io/types_aiobotocore_docs/types_aiobotocore_networkmonitor/)
  service.
- `types-aiobotocore[nimble]` - Type annotations for
  [NimbleStudio](https://youtype.github.io/types_aiobotocore_docs/types_aiobotocore_nimble/)
  service.
- `types-aiobotocore[oam]` - Type annotations for
  [CloudWatchObservabilityAccessManager](https://youtype.github.io/types_aiobotocore_docs/types_aiobotocore_oam/)
  service.
- `types-aiobotocore[omics]` - Type annotations for
  [Omics](https://youtype.github.io/types_aiobotocore_docs/types_aiobotocore_omics/)
  service.
- `types-aiobotocore[opensearch]` - Type annotations for
  [OpenSearchService](https://youtype.github.io/types_aiobotocore_docs/types_aiobotocore_opensearch/)
  service.
- `types-aiobotocore[opensearchserverless]` - Type annotations for
  [OpenSearchServiceServerless](https://youtype.github.io/types_aiobotocore_docs/types_aiobotocore_opensearchserverless/)
  service.
- `types-aiobotocore[opsworks]` - Type annotations for
  [OpsWorks](https://youtype.github.io/types_aiobotocore_docs/types_aiobotocore_opsworks/)
  service.
- `types-aiobotocore[opsworkscm]` - Type annotations for
  [OpsWorksCM](https://youtype.github.io/types_aiobotocore_docs/types_aiobotocore_opsworkscm/)
  service.
- `types-aiobotocore[organizations]` - Type annotations for
  [Organizations](https://youtype.github.io/types_aiobotocore_docs/types_aiobotocore_organizations/)
  service.
- `types-aiobotocore[osis]` - Type annotations for
  [OpenSearchIngestion](https://youtype.github.io/types_aiobotocore_docs/types_aiobotocore_osis/)
  service.
- `types-aiobotocore[outposts]` - Type annotations for
  [Outposts](https://youtype.github.io/types_aiobotocore_docs/types_aiobotocore_outposts/)
  service.
- `types-aiobotocore[panorama]` - Type annotations for
  [Panorama](https://youtype.github.io/types_aiobotocore_docs/types_aiobotocore_panorama/)
  service.
- `types-aiobotocore[payment-cryptography]` - Type annotations for
  [PaymentCryptographyControlPlane](https://youtype.github.io/types_aiobotocore_docs/types_aiobotocore_payment_cryptography/)
  service.
- `types-aiobotocore[payment-cryptography-data]` - Type annotations for
  [PaymentCryptographyDataPlane](https://youtype.github.io/types_aiobotocore_docs/types_aiobotocore_payment_cryptography_data/)
  service.
- `types-aiobotocore[pca-connector-ad]` - Type annotations for
  [PcaConnectorAd](https://youtype.github.io/types_aiobotocore_docs/types_aiobotocore_pca_connector_ad/)
  service.
- `types-aiobotocore[pca-connector-scep]` - Type annotations for
  [PrivateCAConnectorforSCEP](https://youtype.github.io/types_aiobotocore_docs/types_aiobotocore_pca_connector_scep/)
  service.
- `types-aiobotocore[personalize]` - Type annotations for
  [Personalize](https://youtype.github.io/types_aiobotocore_docs/types_aiobotocore_personalize/)
  service.
- `types-aiobotocore[personalize-events]` - Type annotations for
  [PersonalizeEvents](https://youtype.github.io/types_aiobotocore_docs/types_aiobotocore_personalize_events/)
  service.
- `types-aiobotocore[personalize-runtime]` - Type annotations for
  [PersonalizeRuntime](https://youtype.github.io/types_aiobotocore_docs/types_aiobotocore_personalize_runtime/)
  service.
- `types-aiobotocore[pi]` - Type annotations for
  [PI](https://youtype.github.io/types_aiobotocore_docs/types_aiobotocore_pi/)
  service.
- `types-aiobotocore[pinpoint]` - Type annotations for
  [Pinpoint](https://youtype.github.io/types_aiobotocore_docs/types_aiobotocore_pinpoint/)
  service.
- `types-aiobotocore[pinpoint-email]` - Type annotations for
  [PinpointEmail](https://youtype.github.io/types_aiobotocore_docs/types_aiobotocore_pinpoint_email/)
  service.
- `types-aiobotocore[pinpoint-sms-voice]` - Type annotations for
  [PinpointSMSVoice](https://youtype.github.io/types_aiobotocore_docs/types_aiobotocore_pinpoint_sms_voice/)
  service.
- `types-aiobotocore[pinpoint-sms-voice-v2]` - Type annotations for
  [PinpointSMSVoiceV2](https://youtype.github.io/types_aiobotocore_docs/types_aiobotocore_pinpoint_sms_voice_v2/)
  service.
- `types-aiobotocore[pipes]` - Type annotations for
  [EventBridgePipes](https://youtype.github.io/types_aiobotocore_docs/types_aiobotocore_pipes/)
  service.
- `types-aiobotocore[polly]` - Type annotations for
  [Polly](https://youtype.github.io/types_aiobotocore_docs/types_aiobotocore_polly/)
  service.
- `types-aiobotocore[pricing]` - Type annotations for
  [Pricing](https://youtype.github.io/types_aiobotocore_docs/types_aiobotocore_pricing/)
  service.
- `types-aiobotocore[privatenetworks]` - Type annotations for
  [Private5G](https://youtype.github.io/types_aiobotocore_docs/types_aiobotocore_privatenetworks/)
  service.
- `types-aiobotocore[proton]` - Type annotations for
  [Proton](https://youtype.github.io/types_aiobotocore_docs/types_aiobotocore_proton/)
  service.
- `types-aiobotocore[qbusiness]` - Type annotations for
  [QBusiness](https://youtype.github.io/types_aiobotocore_docs/types_aiobotocore_qbusiness/)
  service.
- `types-aiobotocore[qconnect]` - Type annotations for
  [QConnect](https://youtype.github.io/types_aiobotocore_docs/types_aiobotocore_qconnect/)
  service.
- `types-aiobotocore[qldb]` - Type annotations for
  [QLDB](https://youtype.github.io/types_aiobotocore_docs/types_aiobotocore_qldb/)
  service.
- `types-aiobotocore[qldb-session]` - Type annotations for
  [QLDBSession](https://youtype.github.io/types_aiobotocore_docs/types_aiobotocore_qldb_session/)
  service.
- `types-aiobotocore[quicksight]` - Type annotations for
  [QuickSight](https://youtype.github.io/types_aiobotocore_docs/types_aiobotocore_quicksight/)
  service.
- `types-aiobotocore[ram]` - Type annotations for
  [RAM](https://youtype.github.io/types_aiobotocore_docs/types_aiobotocore_ram/)
  service.
- `types-aiobotocore[rbin]` - Type annotations for
  [RecycleBin](https://youtype.github.io/types_aiobotocore_docs/types_aiobotocore_rbin/)
  service.
- `types-aiobotocore[rds]` - Type annotations for
  [RDS](https://youtype.github.io/types_aiobotocore_docs/types_aiobotocore_rds/)
  service.
- `types-aiobotocore[rds-data]` - Type annotations for
  [RDSDataService](https://youtype.github.io/types_aiobotocore_docs/types_aiobotocore_rds_data/)
  service.
- `types-aiobotocore[redshift]` - Type annotations for
  [Redshift](https://youtype.github.io/types_aiobotocore_docs/types_aiobotocore_redshift/)
  service.
- `types-aiobotocore[redshift-data]` - Type annotations for
  [RedshiftDataAPIService](https://youtype.github.io/types_aiobotocore_docs/types_aiobotocore_redshift_data/)
  service.
- `types-aiobotocore[redshift-serverless]` - Type annotations for
  [RedshiftServerless](https://youtype.github.io/types_aiobotocore_docs/types_aiobotocore_redshift_serverless/)
  service.
- `types-aiobotocore[rekognition]` - Type annotations for
  [Rekognition](https://youtype.github.io/types_aiobotocore_docs/types_aiobotocore_rekognition/)
  service.
- `types-aiobotocore[repostspace]` - Type annotations for
  [RePostPrivate](https://youtype.github.io/types_aiobotocore_docs/types_aiobotocore_repostspace/)
  service.
- `types-aiobotocore[resiliencehub]` - Type annotations for
  [ResilienceHub](https://youtype.github.io/types_aiobotocore_docs/types_aiobotocore_resiliencehub/)
  service.
- `types-aiobotocore[resource-explorer-2]` - Type annotations for
  [ResourceExplorer](https://youtype.github.io/types_aiobotocore_docs/types_aiobotocore_resource_explorer_2/)
  service.
- `types-aiobotocore[resource-groups]` - Type annotations for
  [ResourceGroups](https://youtype.github.io/types_aiobotocore_docs/types_aiobotocore_resource_groups/)
  service.
- `types-aiobotocore[resourcegroupstaggingapi]` - Type annotations for
  [ResourceGroupsTaggingAPI](https://youtype.github.io/types_aiobotocore_docs/types_aiobotocore_resourcegroupstaggingapi/)
  service.
- `types-aiobotocore[robomaker]` - Type annotations for
  [RoboMaker](https://youtype.github.io/types_aiobotocore_docs/types_aiobotocore_robomaker/)
  service.
- `types-aiobotocore[rolesanywhere]` - Type annotations for
  [IAMRolesAnywhere](https://youtype.github.io/types_aiobotocore_docs/types_aiobotocore_rolesanywhere/)
  service.
- `types-aiobotocore[route53]` - Type annotations for
  [Route53](https://youtype.github.io/types_aiobotocore_docs/types_aiobotocore_route53/)
  service.
- `types-aiobotocore[route53-recovery-cluster]` - Type annotations for
  [Route53RecoveryCluster](https://youtype.github.io/types_aiobotocore_docs/types_aiobotocore_route53_recovery_cluster/)
  service.
- `types-aiobotocore[route53-recovery-control-config]` - Type annotations for
  [Route53RecoveryControlConfig](https://youtype.github.io/types_aiobotocore_docs/types_aiobotocore_route53_recovery_control_config/)
  service.
- `types-aiobotocore[route53-recovery-readiness]` - Type annotations for
  [Route53RecoveryReadiness](https://youtype.github.io/types_aiobotocore_docs/types_aiobotocore_route53_recovery_readiness/)
  service.
- `types-aiobotocore[route53domains]` - Type annotations for
  [Route53Domains](https://youtype.github.io/types_aiobotocore_docs/types_aiobotocore_route53domains/)
  service.
- `types-aiobotocore[route53profiles]` - Type annotations for
  [Route53Profiles](https://youtype.github.io/types_aiobotocore_docs/types_aiobotocore_route53profiles/)
  service.
- `types-aiobotocore[route53resolver]` - Type annotations for
  [Route53Resolver](https://youtype.github.io/types_aiobotocore_docs/types_aiobotocore_route53resolver/)
  service.
- `types-aiobotocore[rum]` - Type annotations for
  [CloudWatchRUM](https://youtype.github.io/types_aiobotocore_docs/types_aiobotocore_rum/)
  service.
- `types-aiobotocore[s3]` - Type annotations for
  [S3](https://youtype.github.io/types_aiobotocore_docs/types_aiobotocore_s3/)
  service.
- `types-aiobotocore[s3control]` - Type annotations for
  [S3Control](https://youtype.github.io/types_aiobotocore_docs/types_aiobotocore_s3control/)
  service.
- `types-aiobotocore[s3outposts]` - Type annotations for
  [S3Outposts](https://youtype.github.io/types_aiobotocore_docs/types_aiobotocore_s3outposts/)
  service.
- `types-aiobotocore[sagemaker]` - Type annotations for
  [SageMaker](https://youtype.github.io/types_aiobotocore_docs/types_aiobotocore_sagemaker/)
  service.
- `types-aiobotocore[sagemaker-a2i-runtime]` - Type annotations for
  [AugmentedAIRuntime](https://youtype.github.io/types_aiobotocore_docs/types_aiobotocore_sagemaker_a2i_runtime/)
  service.
- `types-aiobotocore[sagemaker-edge]` - Type annotations for
  [SagemakerEdgeManager](https://youtype.github.io/types_aiobotocore_docs/types_aiobotocore_sagemaker_edge/)
  service.
- `types-aiobotocore[sagemaker-featurestore-runtime]` - Type annotations for
  [SageMakerFeatureStoreRuntime](https://youtype.github.io/types_aiobotocore_docs/types_aiobotocore_sagemaker_featurestore_runtime/)
  service.
- `types-aiobotocore[sagemaker-geospatial]` - Type annotations for
  [SageMakergeospatialcapabilities](https://youtype.github.io/types_aiobotocore_docs/types_aiobotocore_sagemaker_geospatial/)
  service.
- `types-aiobotocore[sagemaker-metrics]` - Type annotations for
  [SageMakerMetrics](https://youtype.github.io/types_aiobotocore_docs/types_aiobotocore_sagemaker_metrics/)
  service.
- `types-aiobotocore[sagemaker-runtime]` - Type annotations for
  [SageMakerRuntime](https://youtype.github.io/types_aiobotocore_docs/types_aiobotocore_sagemaker_runtime/)
  service.
- `types-aiobotocore[savingsplans]` - Type annotations for
  [SavingsPlans](https://youtype.github.io/types_aiobotocore_docs/types_aiobotocore_savingsplans/)
  service.
- `types-aiobotocore[scheduler]` - Type annotations for
  [EventBridgeScheduler](https://youtype.github.io/types_aiobotocore_docs/types_aiobotocore_scheduler/)
  service.
- `types-aiobotocore[schemas]` - Type annotations for
  [Schemas](https://youtype.github.io/types_aiobotocore_docs/types_aiobotocore_schemas/)
  service.
- `types-aiobotocore[sdb]` - Type annotations for
  [SimpleDB](https://youtype.github.io/types_aiobotocore_docs/types_aiobotocore_sdb/)
  service.
- `types-aiobotocore[secretsmanager]` - Type annotations for
  [SecretsManager](https://youtype.github.io/types_aiobotocore_docs/types_aiobotocore_secretsmanager/)
  service.
- `types-aiobotocore[securityhub]` - Type annotations for
  [SecurityHub](https://youtype.github.io/types_aiobotocore_docs/types_aiobotocore_securityhub/)
  service.
- `types-aiobotocore[securitylake]` - Type annotations for
  [SecurityLake](https://youtype.github.io/types_aiobotocore_docs/types_aiobotocore_securitylake/)
  service.
- `types-aiobotocore[serverlessrepo]` - Type annotations for
  [ServerlessApplicationRepository](https://youtype.github.io/types_aiobotocore_docs/types_aiobotocore_serverlessrepo/)
  service.
- `types-aiobotocore[service-quotas]` - Type annotations for
  [ServiceQuotas](https://youtype.github.io/types_aiobotocore_docs/types_aiobotocore_service_quotas/)
  service.
- `types-aiobotocore[servicecatalog]` - Type annotations for
  [ServiceCatalog](https://youtype.github.io/types_aiobotocore_docs/types_aiobotocore_servicecatalog/)
  service.
- `types-aiobotocore[servicecatalog-appregistry]` - Type annotations for
  [AppRegistry](https://youtype.github.io/types_aiobotocore_docs/types_aiobotocore_servicecatalog_appregistry/)
  service.
- `types-aiobotocore[servicediscovery]` - Type annotations for
  [ServiceDiscovery](https://youtype.github.io/types_aiobotocore_docs/types_aiobotocore_servicediscovery/)
  service.
- `types-aiobotocore[ses]` - Type annotations for
  [SES](https://youtype.github.io/types_aiobotocore_docs/types_aiobotocore_ses/)
  service.
- `types-aiobotocore[sesv2]` - Type annotations for
  [SESV2](https://youtype.github.io/types_aiobotocore_docs/types_aiobotocore_sesv2/)
  service.
- `types-aiobotocore[shield]` - Type annotations for
  [Shield](https://youtype.github.io/types_aiobotocore_docs/types_aiobotocore_shield/)
  service.
- `types-aiobotocore[signer]` - Type annotations for
  [Signer](https://youtype.github.io/types_aiobotocore_docs/types_aiobotocore_signer/)
  service.
- `types-aiobotocore[simspaceweaver]` - Type annotations for
  [SimSpaceWeaver](https://youtype.github.io/types_aiobotocore_docs/types_aiobotocore_simspaceweaver/)
  service.
- `types-aiobotocore[sms]` - Type annotations for
  [SMS](https://youtype.github.io/types_aiobotocore_docs/types_aiobotocore_sms/)
  service.
- `types-aiobotocore[sms-voice]` - Type annotations for
  [PinpointSMSVoice](https://youtype.github.io/types_aiobotocore_docs/types_aiobotocore_sms_voice/)
  service.
- `types-aiobotocore[snow-device-management]` - Type annotations for
  [SnowDeviceManagement](https://youtype.github.io/types_aiobotocore_docs/types_aiobotocore_snow_device_management/)
  service.
- `types-aiobotocore[snowball]` - Type annotations for
  [Snowball](https://youtype.github.io/types_aiobotocore_docs/types_aiobotocore_snowball/)
  service.
- `types-aiobotocore[sns]` - Type annotations for
  [SNS](https://youtype.github.io/types_aiobotocore_docs/types_aiobotocore_sns/)
  service.
- `types-aiobotocore[sqs]` - Type annotations for
  [SQS](https://youtype.github.io/types_aiobotocore_docs/types_aiobotocore_sqs/)
  service.
- `types-aiobotocore[ssm]` - Type annotations for
  [SSM](https://youtype.github.io/types_aiobotocore_docs/types_aiobotocore_ssm/)
  service.
- `types-aiobotocore[ssm-contacts]` - Type annotations for
  [SSMContacts](https://youtype.github.io/types_aiobotocore_docs/types_aiobotocore_ssm_contacts/)
  service.
- `types-aiobotocore[ssm-incidents]` - Type annotations for
  [SSMIncidents](https://youtype.github.io/types_aiobotocore_docs/types_aiobotocore_ssm_incidents/)
  service.
- `types-aiobotocore[ssm-sap]` - Type annotations for
  [SsmSap](https://youtype.github.io/types_aiobotocore_docs/types_aiobotocore_ssm_sap/)
  service.
- `types-aiobotocore[sso]` - Type annotations for
  [SSO](https://youtype.github.io/types_aiobotocore_docs/types_aiobotocore_sso/)
  service.
- `types-aiobotocore[sso-admin]` - Type annotations for
  [SSOAdmin](https://youtype.github.io/types_aiobotocore_docs/types_aiobotocore_sso_admin/)
  service.
- `types-aiobotocore[sso-oidc]` - Type annotations for
  [SSOOIDC](https://youtype.github.io/types_aiobotocore_docs/types_aiobotocore_sso_oidc/)
  service.
- `types-aiobotocore[stepfunctions]` - Type annotations for
  [SFN](https://youtype.github.io/types_aiobotocore_docs/types_aiobotocore_stepfunctions/)
  service.
- `types-aiobotocore[storagegateway]` - Type annotations for
  [StorageGateway](https://youtype.github.io/types_aiobotocore_docs/types_aiobotocore_storagegateway/)
  service.
- `types-aiobotocore[sts]` - Type annotations for
  [STS](https://youtype.github.io/types_aiobotocore_docs/types_aiobotocore_sts/)
  service.
- `types-aiobotocore[supplychain]` - Type annotations for
  [SupplyChain](https://youtype.github.io/types_aiobotocore_docs/types_aiobotocore_supplychain/)
  service.
- `types-aiobotocore[support]` - Type annotations for
  [Support](https://youtype.github.io/types_aiobotocore_docs/types_aiobotocore_support/)
  service.
- `types-aiobotocore[support-app]` - Type annotations for
  [SupportApp](https://youtype.github.io/types_aiobotocore_docs/types_aiobotocore_support_app/)
  service.
- `types-aiobotocore[swf]` - Type annotations for
  [SWF](https://youtype.github.io/types_aiobotocore_docs/types_aiobotocore_swf/)
  service.
- `types-aiobotocore[synthetics]` - Type annotations for
  [Synthetics](https://youtype.github.io/types_aiobotocore_docs/types_aiobotocore_synthetics/)
  service.
- `types-aiobotocore[taxsettings]` - Type annotations for
  [TaxSettings](https://youtype.github.io/types_aiobotocore_docs/types_aiobotocore_taxsettings/)
  service.
- `types-aiobotocore[textract]` - Type annotations for
  [Textract](https://youtype.github.io/types_aiobotocore_docs/types_aiobotocore_textract/)
  service.
- `types-aiobotocore[timestream-influxdb]` - Type annotations for
  [TimestreamInfluxDB](https://youtype.github.io/types_aiobotocore_docs/types_aiobotocore_timestream_influxdb/)
  service.
- `types-aiobotocore[timestream-query]` - Type annotations for
  [TimestreamQuery](https://youtype.github.io/types_aiobotocore_docs/types_aiobotocore_timestream_query/)
  service.
- `types-aiobotocore[timestream-write]` - Type annotations for
  [TimestreamWrite](https://youtype.github.io/types_aiobotocore_docs/types_aiobotocore_timestream_write/)
  service.
- `types-aiobotocore[tnb]` - Type annotations for
  [TelcoNetworkBuilder](https://youtype.github.io/types_aiobotocore_docs/types_aiobotocore_tnb/)
  service.
- `types-aiobotocore[transcribe]` - Type annotations for
  [TranscribeService](https://youtype.github.io/types_aiobotocore_docs/types_aiobotocore_transcribe/)
  service.
- `types-aiobotocore[transfer]` - Type annotations for
  [Transfer](https://youtype.github.io/types_aiobotocore_docs/types_aiobotocore_transfer/)
  service.
- `types-aiobotocore[translate]` - Type annotations for
  [Translate](https://youtype.github.io/types_aiobotocore_docs/types_aiobotocore_translate/)
  service.
- `types-aiobotocore[trustedadvisor]` - Type annotations for
  [TrustedAdvisorPublicAPI](https://youtype.github.io/types_aiobotocore_docs/types_aiobotocore_trustedadvisor/)
  service.
- `types-aiobotocore[verifiedpermissions]` - Type annotations for
  [VerifiedPermissions](https://youtype.github.io/types_aiobotocore_docs/types_aiobotocore_verifiedpermissions/)
  service.
- `types-aiobotocore[voice-id]` - Type annotations for
  [VoiceID](https://youtype.github.io/types_aiobotocore_docs/types_aiobotocore_voice_id/)
  service.
- `types-aiobotocore[vpc-lattice]` - Type annotations for
  [VPCLattice](https://youtype.github.io/types_aiobotocore_docs/types_aiobotocore_vpc_lattice/)
  service.
- `types-aiobotocore[waf]` - Type annotations for
  [WAF](https://youtype.github.io/types_aiobotocore_docs/types_aiobotocore_waf/)
  service.
- `types-aiobotocore[waf-regional]` - Type annotations for
  [WAFRegional](https://youtype.github.io/types_aiobotocore_docs/types_aiobotocore_waf_regional/)
  service.
- `types-aiobotocore[wafv2]` - Type annotations for
  [WAFV2](https://youtype.github.io/types_aiobotocore_docs/types_aiobotocore_wafv2/)
  service.
- `types-aiobotocore[wellarchitected]` - Type annotations for
  [WellArchitected](https://youtype.github.io/types_aiobotocore_docs/types_aiobotocore_wellarchitected/)
  service.
- `types-aiobotocore[wisdom]` - Type annotations for
  [ConnectWisdomService](https://youtype.github.io/types_aiobotocore_docs/types_aiobotocore_wisdom/)
  service.
- `types-aiobotocore[workdocs]` - Type annotations for
  [WorkDocs](https://youtype.github.io/types_aiobotocore_docs/types_aiobotocore_workdocs/)
  service.
- `types-aiobotocore[worklink]` - Type annotations for
  [WorkLink](https://youtype.github.io/types_aiobotocore_docs/types_aiobotocore_worklink/)
  service.
- `types-aiobotocore[workmail]` - Type annotations for
  [WorkMail](https://youtype.github.io/types_aiobotocore_docs/types_aiobotocore_workmail/)
  service.
- `types-aiobotocore[workmailmessageflow]` - Type annotations for
  [WorkMailMessageFlow](https://youtype.github.io/types_aiobotocore_docs/types_aiobotocore_workmailmessageflow/)
  service.
- `types-aiobotocore[workspaces]` - Type annotations for
  [WorkSpaces](https://youtype.github.io/types_aiobotocore_docs/types_aiobotocore_workspaces/)
  service.
- `types-aiobotocore[workspaces-thin-client]` - Type annotations for
  [WorkSpacesThinClient](https://youtype.github.io/types_aiobotocore_docs/types_aiobotocore_workspaces_thin_client/)
  service.
- `types-aiobotocore[workspaces-web]` - Type annotations for
  [WorkSpacesWeb](https://youtype.github.io/types_aiobotocore_docs/types_aiobotocore_workspaces_web/)
  service.
- `types-aiobotocore[xray]` - Type annotations for
  [XRay](https://youtype.github.io/types_aiobotocore_docs/types_aiobotocore_xray/)
  service.
